library(mitml)
library(plyr)
library(lme4)

# read stacked imputation data
setwd(dirname(rstudioapi::getActiveDocumentContext()$path))
impdata <- read.table(paste0(getwd(),"/imps_stacked.dat"))
names(impdata) <- c("imputation", "school", "student", "wave", "condition", "eslpct", "ethnic", "male", "frlunch", "achvgrp", "stanmath", "month0", "month7", "probsolv", "matheff")
impdata <- impdata[impdata$imputation > 0, ]

# center covariates at grand means
impdata <- ddply(impdata, c("imputation"), transform, malec = scale(male, center = T, scale = F))
impdata <- ddply(impdata, c("imputation"), transform, frlunchc = scale(frlunch, center = T, scale = F))
impdata <- ddply(impdata, c("imputation"), transform, stanmathc = scale(stanmath, center = T, scale = F))

# analysis and pooling
implist <- as.mitml.list(split(impdata, impdata$imputation))
model <- "probsolv ~ month0  + condition + month0*condition + malec + frlunchc + stanmathc +  (month0 | student)"
analysis <- with(implist, lmer(model, REML = F))
estimates <- testEstimates(analysis, var.comp = T, df.com = NULL)
estimates

# estimate empty model with no predictors
emptymodel <- with(implist, lmer(probsolv ~ 1 + (month0 | student)))

# compare models with Wald test (e.g., MI version of omnibus F test)
testModels(analysis, emptymodel, method = "D1")

# compare models with likelihood ratio test (e.g., MI version of chi-square diff)
testModels(analysis, emptymodel, method = "D3")
