# load lavaan sem package with semtools
library(lavaan)
library(semTools)

# read stacked data
setwd(dirname(rstudioapi::getActiveDocumentContext()$path))
paindata <- read.table(paste0(getwd(),"/pain.dat"))
names(paindata) <- c("id", "male", "age", "edugroup", "workhrs", "exercise", "pain", "anxiety", "stress", "control", "interfere", "depress", "disability")

# missing data code
paindata[paindata == 999] <- NA

# auxiliary variables
auxvars <- c("anxiety", "control")

# specify model and label parameters for wald test
model <- '
disability ~ b1*depress + b2*male
depress ~~ male
'

# fit <- sem(model, lmxdata, missing = 'fiml', fixed.x = F, meanstructure = T, mimic = "Mplus")
analysis <- sem.auxiliary(model = model, aux = auxvars, data = paindata, missing = 'fiml', fixed.x = F, meanstructure = T, mimic = "Mplus")
summary(analysis, fit.measures = T, rsquare = T, standardize = T)

# wald significance test (omnibus test of all predictors)
lavTestWald(analysis, 'b1 == 0 
            b2 == 0')
